All pastes #831008 Raw Edit

Unnamed

public text v1 · immutable
#831008 ·published 2007-12-24 13:46 UTC
rendered paste body
nvidia-installer log file '/var/log/nvidia-installer.log'
creation time: Mon Dec 24 11:31:54 2007

option status:
  license pre-accepted    : false
  update                  : false
  force update            : false
  expert                  : false
  uninstall               : false
  driver info             : false
  precompiled interfaces  : true
  no ncurses color        : false
  query latest version    : false
  OpenGL header files     : true
  no questions            : false
  silent                  : false
  no recursion            : false
  no backup               : false
  kernel module only      : false
  sanity                  : false
  add this kernel         : false
  no runlevel check       : false
  no network              : false
  no ABI note             : false
  no RPMs                 : false
  no kernel module        : false
  force SELinux           : default
  no X server check       : false
  force tls               : (not specified)
  X install prefix        : (not specified)
  X library install path  : (not specified)
  X module install path   : (not specified)
  OpenGL install prefix   : (not specified)
  OpenGL install libdir   : (not specified)
  utility install prefix  : (not specified)
  utility install libdir  : (not specified)
  doc install prefix      : (not specified)
  kernel name             : (not specified)
  kernel include path     : (not specified)
  kernel source path      : (not specified)
  kernel output path      : (not specified)
  kernel install path     : (not specified)
  proc mount point        : /proc
  ui                      : (not specified)
  tmpdir                  : /tmp
  ftp mirror              : ftp://download.nvidia.com
  RPM file list           : (not specified)

Using: nvidia-installer ncurses user interface
-> License accepted.
-> There appears to already be a driver installed on your system (version: 1.0-
   9639).  As part of installing this driver (version: 1.0-9629), the existing 
   driver will be uninstalled.  Are you sure you want to continue? ('no' will a
   bort installation) (Answer: Yes)
-> No precompiled kernel interface was found to match your kernel; would you li
   ke the installer to attempt to download a kernel interface for your kernel f
   rom the NVIDIA ftp site (ftp://download.nvidia.com)? (Answer: No)
-> No precompiled kernel interface was found to match your kernel; this means
   that the installer will need to compile a new kernel interface.
-> Performing CC sanity check with CC="cc".
-> Performing CC version check with CC="cc".
-> Kernel source path: '/lib/modules/2.6.20-16-generic/build'
-> Kernel output path: '/lib/modules/2.6.20-16-generic/build'
-> Performing rivafb check.
-> Performing nvidiafb check.
-> Cleaning kernel module build directory.
   executing: 'cd ./usr/src/nv; make clean'...
   rm -f -f nv.o nv-vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nv.o nv
   -vm.o os-agp.o os-interface.o os-registry.o nv-i2c.o nvidia.mod.o
   rm -f -f build-in.o nv-linux.o *.d .*.{cmd,flags}
   rm -f -f nvidia.{o,ko,mod.{o,c}} nv_compiler.h *~
   rm -f -f stprof stprof.o symtab.h Modules.symvers
   rm -f -rf .tmp_versions
-> Building kernel module:
   executing: 'cd ./usr/src/nv; make module SYSSRC=/lib/modules/2.6.20-16-gener
   ic/build SYSOUT=/lib/modules/2.6.20-16-generic/build'...
   
   NVIDIA: calling KBUILD...
   make CC=cc  KBUILD_VERBOSE=1 -C /lib/modules/2.6.20-16-generic/build SUBDIRS
   =/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv modules
   test -e include/linux/autoconf.h -a -e include/config/auto.conf || (		\
   	echo;								\
   	echo "  ERROR: Kernel configuration is invalid.";		\
   	echo "         include/linux/autoconf.h or include/config/auto.conf are mis
   sing.";	\
   	echo "         Run 'make oldconfig && make prepare' on kernel src to fix it
   .";	\
   	echo;								\
   	/bin/false)
   mkdir -p /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp_ver
   sions
   rm -f /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp_versio
   ns/*
   make -f scripts/Makefile.build obj=/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv
   echo \#define NV_COMPILER \"`cc -v 2>&1 | tail -n 1`\" > /tmp/selfgz10534/NV
   IDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv_compiler.h
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.nv.
   o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KERNEL
   __ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  -Wall -Wun
   def -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -O2 
   -pipe -msoft-float -mregparm=3 -mpreferred-stack-boundary=2  -march=i586 -mt
   une=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i386/m
   ach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-afte
   r-statement -Wno-pointer-sign -I/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-p
   kg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-subsc
   ripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-common 
   -msoft-float -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_
   NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=
   0 -DNV_PATCHLEVEL=9629  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -D
   NV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MA
   X_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT 
   -DNV_VM_IN
   SERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_P
   RESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD
   _STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv)"  -D"KBUILD_MODNAME=KBUILD_STR
   (nvidia)" -c -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.
   tmp_nv.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
   /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv.c: At top leve
   l:
   /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv.c:110: warning
   : ‘kmem_cache_t’ is deprecated
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.nv-
   vm.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KER
   NEL__ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  -Wall -
   Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common -
   O2 -pipe -msoft-float -mregparm=3 -mpreferred-stack-boundary=2  -march=i586 
   -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i38
   6/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-a
   fter-statement -Wno-pointer-sign -I/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-su
   bscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-comm
   on -msoft-float -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERN
   EL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_V
   ERSION=0 -DNV_PATCHLEVEL=9629  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_
   RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SY
   SCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_P
   RESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_
   REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -
   DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nv_vm)"  -D"KBUIL
   D_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-96
   29-pkg1/usr/src/nv/.tmp_nv-vm.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-p
   kg1/usr/src/nv/nv-vm.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-vm.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.os-
   agp.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  -Wall 
   -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common 
   -O2 -pipe -msoft-float -mregparm=3 -mpreferred-stack-boundary=2  -march=i586
   -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i38
   6/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-a
   fter-statement -Wno-pointer-sign -I/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -Wchar-su
   bscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -fno-comm
   on -msoft-float -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERN
   EL_N
   AMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0
   -DNV_PATCHLEVEL=9629  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV
   _MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_
   MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -D
   NV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN
   _RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -
   D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_agp)"  -D"KBUILD_MODNAM
   E=KBUILD_STR(nvidia)" -c -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/
   usr/src/nv/.tmp_os-agp.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr
   /src/nv/os-agp.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/os-agp.c:24:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.os-
   interface.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include 
   -D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  
   -Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-c
   ommon -O2 -pipe -msoft-float -mregparm=3 -mpreferred-stack-boundary=2  -marc
   h=i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/
   asm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclar
   ation-after-statement -Wno-pointer-sign -I/tmp/selfgz10534/NVIDIA-Linux-x86-
   1.0-9629-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wswitch -Wformat -W
   char-subscripts -Wparentheses -Wpointer-arith  -Wno-multichar  -Werror -O -f
   no-common
    -msoft-float -MD   -Wsign-compare -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL
   _NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION
   =0 -DNV_PATCHLEVEL=9629  -UDEBUG -U_DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -
   DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_M
   AX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT
   -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_P
   FN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE
   -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(os_interface)"  -D"KBUILD
   _MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv/.tmp_os-interface.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-
   9629-pkg1/usr/src/nv/os-interface.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/os-interface.c:26:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.os-
   registry.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -
   D__KERNEL__ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  -
   Wall -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-co
   mmon -O2 -pipe -msoft-float -mregparm=3 -mpreferred-stack-boundary=2  -march
   =i586 -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/a
   sm-i386/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclara
   tion-after-statement -Wno-pointer-sign -I/tmp/selfgz10534/NVIDIA-Linux-x86-1
   .0-9629-pkg1/usr/src/nv -Wall -Wimplicit -Wreturn-type -Wsw
   itch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arith  -Wno-multicha
   r  -Werror -O -fno-common -msoft-float -MD   -Wsign-compare -Wno-cast-qual -
   Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVRM -DNV_MAJOR_VER
   SION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629  -UDEBUG -U_DEBUG -DNDEBUG 
   -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT -DNV_PCI_GET_CL
   ASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE_T_PRESENT -DNV
   _PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OLD_MM_KGDB_BREAK
   POINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_ATTR_PRESENT -DN
   V_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_ST
   R(os_registry)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/selfgz1053
   4/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp_os-registry.o /tmp/selfgz10
   534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-registry.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/os-registry.c:14:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.nv-
   i2c.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D__KE
   RNEL__ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  -Wall 
   -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-common 
   -O2 -pipe -msoft-float -mregparm=3 -mpreferred-stack-boundary=2  -march=i586
   -mtune=generic -ffreestanding -maccumulate-outgoing-args   -Iinclude/asm-i38
   6/mach-default -fomit-frame-pointer -g  -fno-stack-protector -Wdeclaration-a
   fter-statement -Wno-pointer-sign -I/t
   mp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv -Wall -Wimplicit -W
   return-type -Wswitch -Wformat -Wchar-subscripts -Wparentheses -Wpointer-arit
   h  -Wno-multichar  -Werror -O -fno-common -msoft-float -MD   -Wsign-compare 
   -Wno-cast-qual -Wno-error -D_LOOSE_KERNEL_NAMES -D__KERNEL__ -DMODULE  -DNVR
   M -DNV_MAJOR_VERSION=1 -DNV_MINOR_VERSION=0 -DNV_PATCHLEVEL=9629  -UDEBUG -U
   _DEBUG -DNDEBUG -DNV_SIGNAL_STRUCT_RLIM -DNV_MULTIPLE_BRIDGE_AGPGART_PRESENT
   -DNV_PCI_GET_CLASS_PRESENT -DNV_SYSCTL_MAX_MAP_COUNT_PRESENT -DNV_PM_MESSAGE
   _T_PRESENT -DNV_PCI_CHOOSE_STATE_PRESENT -DNV_VM_INSERT_PAGE_PRESENT -DNV_OL
   D_MM_KGDB_BREAKPOINT_PRESENT -DNV_REMAP_PFN_RANGE_PRESENT -DNV_CHANGE_PAGE_A
   TTR_PRESENT -DNV_VMAP_4_PRESENT  -DMODULE -D"KBUILD_STR(s)=#s" -D"KBUILD_BAS
   ENAME=KBUILD_STR(nv_i2c)"  -D"KBUILD_MODNAME=KBUILD_STR(nvidia)" -c -o /tmp/
   selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.tmp_nv-i2c.o /tmp/sel
   fgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv-i2c.c
   In file included from include/linux/list.h:8,
                    from include/linux/wait.h:22,
                    from include/asm/semaphore.h:41,
                    from include/linux/sched.h:59,
                    from include/linux/utsname.h:35,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-linux.h:19,
                    from /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-i2c.c:8:
   include/linux/prefetch.h: In function ‘prefetch_range’:
   include/linux/prefetch.h:62: warning: pointer of type ‘void *’ used in a
   rithmetic
     ld -m elf_i386 -m elf_i386  -r -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-96
   29-pkg1/usr/src/nv/nvidia.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/
   usr/src/nv/nv-kernel.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/s
   rc/nv/nv.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/nv-vm.
   o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-agp.o /tmp/s
   elfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/os-interface.o /tmp/sel
   fgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr
   /src/nv/os-registry.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/sr
   c/nv/nv-i2c.o
     Building modules, stage 2.
   make -f /usr/src/linux-headers-2.6.20-16-generic/scripts/Makefile.modpost
     scripts/mod/modpost -m -a -i /usr/src/linux-headers-2.6.20-16-generic/Modu
   le.symvers -I /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/Mod
   ule.symvers -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/Mo
   dule.symvers -w  /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/
   nvidia.o
   WARNING: could not find /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/
   src/nv/.nv-kernel.o.cmd for /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/
   usr/src/nv/nv-kernel.o
     cc -Wp,-MD,/tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/nv/.nvi
   dia.mod.o.d  -nostdinc -isystem /usr/lib/gcc/i486-linux-gnu/4.1.2/include -D
   __KERNEL__ -Iinclude  -include include/linux/autoconf.h -Iubuntu/include  -W
   all -Wundef -Wstrict-prototypes -Wno-trigraphs -fno-strict-aliasing -fno-com
   mon -O2 -pipe -msoft-float -mregparm=3 
   -mpreferred-stack-boundary=2  -march=i586 -mtune=generic -ffreestanding -mac
   cumulate-outgoing-args   -Iinclude/asm-i386/mach-default -fomit-frame-pointe
   r -g  -fno-stack-protector -Wdeclaration-after-statement -Wno-pointer-sign  
    -D"KBUILD_STR(s)=#s" -D"KBUILD_BASENAME=KBUILD_STR(nvidia.mod)"  -D"KBUILD_
   MODNAME=KBUILD_STR(nvidia)" -DMODULE -c -o /tmp/selfgz10534/NVIDIA-Linux-x86
   -1.0-9629-pkg1/usr/src/nv/nvidia.mod.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0
   -9629-pkg1/usr/src/nv/nvidia.mod.c
     ld -m elf_i386 -m elf_i386 -r -o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-962
   9-pkg1/usr/src/nv/nvidia.ko /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/
   usr/src/nv/nvidia.o /tmp/selfgz10534/NVIDIA-Linux-x86-1.0-9629-pkg1/usr/src/
   nv/nvidia.mod.o
   NVIDIA: left KBUILD.
-> done.
-> Kernel module compilation complete.
-> Kernel messages:
   [   53.650465] NVRM: this kernel module has the version 1.0-9631.  Please
   [   53.650467] NVRM: make sure that this kernel module and all NVIDIA driver
   [   53.650469] NVRM: components have the same version.
   [   57.797792] NVRM: API mismatch: the client has the version 1.0-9639, but
   [   57.797797] NVRM: this kernel module has the version 1.0-9631.  Please
   [   57.797799] NVRM: make sure that this kernel module and all NVIDIA driver
   [   57.797801] NVRM: components have the same version.
   [   57.967630] parport0: no more devices allowed
   [   57.967640] lp: driver loaded but no devices found
   [   57.996883] ppdev: user-space parallel port driver
   [   58.229492] apm: BIOS not found.
   [   59.643996] vboxdrv: Trying to deactivate the NMI watchdog permanently...
   [   59.644006] vboxdrv: Successfully done.
   [   60.943258] loop: loaded (max 8 devices)
   [   61.092213] ISO 9660 Extensions: Microsoft Joliet Level 3
   [   61.092678] ISOFS: changing to secondary root
   [   61.872554] NVRM: API mismatch: the client has the version 1.0-9639, but
   [   61.872558] NVRM: this kernel module has the version 1.0-9631.  Please
   [   61.872560] NVRM: make sure that this kernel module and all NVIDIA driver
   [   61.872561] NVRM: components have the same version.
   [  138.690673] NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9639  Mon
   Apr 16 20:20:06 PDT 2007
   [  825.488760] NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9639  Mon
   Apr 16 20:20:06 PDT 2007
   [ 1090.998471] NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9639  Mon
   Apr 16 20:20:06 PDT 2007
   [ 1514.523368] NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9639  Mon
   Apr 16 20:20:06 PDT 2007
   [ 1756.455829] NVRM: loading NVIDIA Linux x86 Kernel Module  1.0-9629  Wed
   Nov  1 19:30:07 PST 2006
WARNING: You appear to be using a modular X.Org release, but nvidia-installer
         was unable to determine the correct X library installation path with
         the `pkg-config` utility.  Please install the X.Org SDK/development
         package for your distribution.
WARNING: nvidia-installer was unable to determine the correct X library
         installation path and will install the NVIDIA X libraries to
         '/usr/lib'.
WARNING: You appear to be using a modular X.Org release, but nvidia-installer
         was unable to determine the correct X module installation path with
         the `pkg-config` utility.  Please install the X.Org SDK/development
         package for your distribution.
WARNING: nvidia-installer was unable to determine the correct X module
         installation path and will install the NVIDIA X driver components to
         '/usr/lib/xorg/modules'.  If X fails to find the NVIDIA X driver
         module, please correct any `pkg-config` problems warned about earlier
         and reinstall the driver.
-> Installing both new and classic TLS OpenGL libraries.
-> Parsing log file:
-> done.
-> Validating previous installation:
-> Unable to access previously installed symlink '/usr/lib/libGL.so.1' (No such
   file or directory).
-> Unable to access previously installed symlink '/usr/lib/libGL.so' (No such
   file or directory).
-> Unable to access previously installed symlink '/usr/lib/libGLcore.so.1' (No
   such file or directory).
-> Unable to access previously installed symlink '/usr/lib/libnvidia-tls.so.1'
   (No such file or directory).
-> Unable to access previously installed symlink
   '/usr/lib/tls/libnvidia-tls.so.1' (No such file or directory).
-> Unable to access previously installed symlink '/usr/lib/libnvidia-cfg.so.1'
   (No such file or directory).
-> Unable to access previously installed symlink '/usr/lib/libnvidia-cfg.so'
   (No such file or directory).
-> Unable to access previously installed symlink
   '/usr/lib/xorg/modules/extensions/libglx.so' (No such file or directory).
-> Unable to access previously installed symlink
   '/usr/lib/libXvMCNVIDIA_dynamic.so.1' (No such file or directory).
-> done.
WARNING: Your driver installation has been altered since it was initially
         installed; this may happen, for example, if you have since installed
         the NVIDIA driver through a mechanism other than the nvidia-installer
         (such as rpm or with the NVIDIA tarballs).  The nvidia-installer will
         attempt to uninstall as best it can.  Please see the file
         '/var/log/nvidia-installer.log' for details.
-> Uninstalling NVIDIA Accelerated Graphics Driver for Linux-x86 (1.0-9639):
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/lib/libGL.so.1.0.9639' for copying (No such file or directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/lib/libGL.so.1.0.9639'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/lib/libnvidia-cfg.so.1.0.9639' for copying (No such file or
       directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/lib/libnvidia-cfg.so.1.0.9639'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/lib/libGL.la' for copying (No such file or directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/lib/libGL.la'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/lib/libGLcore.so.1.0.9639' for copying (No such file or directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/lib/libGLcore.so.1.0.9639'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/X11R6/lib/libXvMCNVIDIA.so.1.0.9639' for copying (No such file or
       directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/X11R6/lib/libXvMCNVIDIA.so.1.0.9639'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/X11R6/lib/modules/drivers/nvidia_drv.so' for copying (No such file or
       directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/X11R6/lib/modules/drivers/nvidia_drv.so'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/X11R6/lib/modules/extensions/libglx.so.1.0.9639' for copying (No such
       file or directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/X11R6/lib/modules/extensions/libglx.so.1.0.9639'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/X11R6/lib/libXvMCNVIDIA.a' for copying (No such file or directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/X11R6/lib/libXvMCNVIDIA.a'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/lib/tls/libnvidia-tls.so.1.0.9639' for copying (No such file or
       directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/lib/tls/libnvidia-tls.so.1.0.9639'.
ERROR: Unable to create
       '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1/u
       sr/lib/libnvidia-tls.so.1.0.9639' for copying (No such file or
       directory)
WARNING: Unable to restore file
         '/usr/lib/dosemu/freedos/tmp/selfgz9429/NVIDIA-Linux-x86-1.0-9639-pkg1
         /usr/lib/libnvidia-tls.so.1.0.9639'.
-> done.
-> Uninstallation of existing driver: NVIDIA Accelerated Graphics Driver for
   Linux-x86 (1.0-9639) is complete.
-> Searching for conflicting X files:
-> done.
-> Searching for conflicting OpenGL files:
-> done.
-> Installing 'NVIDIA Accelerated Graphics Driver for Linux-x86' (1.0-9629):
ERROR: Unable to open './usr/lib/libGL.so.1.0.9629' for copying (No such file
       or directory)
-> The installer has encountered the following error during installation: 'Cann
   ot install /usr/lib/libGL.so.1.0.9629'.  Continue anyway? ("no" will abort)?
   (Answer: Yes)
ERROR: Unable to open './usr/lib/libGLcore.so.1.0.9629' for copying (No such
       file or directory)
-> The installer has encountered the following error during installation: 'Cann
   ot install /usr/lib/libGLcore.so.1.0.9629'.  Continue anyway? ("no" will abo
   rt)? (Answer: Yes)
ERROR: Unable to open './usr/lib/libnvidia-tls.so.1.0.9629' for copying (No
       such file or directory)
-> The installer has encountered the following error during installation: 'Cann
   ot install /usr/lib/libnvidia-tls.so.1.0.9629'.  Continue anyway? ("no" will
   abort)? (Answer: Yes)